@@ -1,23 +1,28 @@
 package Dist::Zilla;
-$Dist::Zilla::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::VERSION = '3.101390';
+}
 # ABSTRACT: distribution builder; installer not included!
 use Moose 0.92; # role composition fixes
 with 'Dist::Zilla::Role::ConfigDumper';
 
 use Moose::Autobox 0.09; # ->flatten
-use Dist::Zilla::Types qw(DistName License);
+use Dist::Zilla::Types qw(License);
 use MooseX::Types::Moose qw(Bool HashRef);
+use MooseX::Types::Perl qw(DistName LaxVersionStr);
 use MooseX::Types::Path::Class qw(Dir File);
 use Moose::Util::TypeConstraints;
 
+use Archive::Tar;
 use File::Find::Rule;
+use File::pushd ();
 use Hash::Merge::Simple ();
 use List::MoreUtils qw(uniq);
 use List::Util qw(first);
 use Log::Dispatchouli 1.100712; # proxy_loggers, quiet_fatal
 use Params::Util qw(_HASHLIKE);
-use Path::Class ();
-use Software::License;
+use Path::Class;
+use Software::License 0.101370; # meta2_name
 use String::RewritePrefix;
 
 use Dist::Zilla::Prereqs;
@@ -28,9 +33,10 @@ use Dist::Zilla::Util;
 use namespace::autoclean;
 
 
-has controller => (
+has chrome => (
   is  => 'rw',
-  isa => 'Dist::Zilla::App',
+  isa => 'Object', # will be does => 'Dist::Zilla::Role::Chrome' when it exists
+  required => 1,
 );
 
 
@@ -50,7 +56,7 @@ has version_override => (
 # XXX: *clearly* this needs to be really much smarter -- rjbs, 2008-06-01
 has version => (
   is   => 'rw',
-  isa  => 'Str',
+  isa  => LaxVersionStr,
   lazy => 1,
   init_arg  => undef,
   required  => 1,
@@ -72,9 +78,6 @@ sub _build_version {
 
   $self->log_fatal('no version was ever set') unless defined $version;
 
-  $self->log("warning: version number does not look like a number")
-    unless $version =~ m{\A\d+(?:\.\d+)\z};
-
   $version;
 }
 
@@ -288,17 +291,18 @@ sub _build_distmeta {
 
   my $meta = {
     'meta-spec' => {
-      version => 1.4,
-      url     => 'http://module-build.sourceforge.net/META-spec-v1.4.html',
+      version => 2,
+      url     => 'http://github.com/dagolden/cpan-meta/',
     },
     name     => $self->name,
     version  => $self->version,
     abstract => $self->abstract,
     author   => $self->authors,
-    license  => $self->license->meta_yml_name,
-    generated_by => (ref $self)
-                  . ' version '
-                  . (defined $self->VERSION ? $self->VERSION : '(undef)')
+    license  => $self->license->meta2_name,
+    dynamic_config => 0,
+    generated_by   => (ref $self)
+                    . ' version '
+                    . (defined $self->VERSION ? $self->VERSION : '(undef)')
   };
 
   $meta = Hash::Merge::Simple::merge($meta, $_->metadata)
@@ -308,7 +312,7 @@ sub _build_distmeta {
 }
 
 
-has prereq => (
+has prereqs => (
   is   => 'ro',
   isa  => 'Dist::Zilla::Prereqs',
   init_arg => undef,
@@ -321,25 +325,21 @@ sub from_config {
   my ($class, $arg) = @_;
   $arg ||= {};
 
-  my $root = Path::Class::dir($arg->{dist_root} || '.');
-
-  my $logger = $arg->{logger} || $class->default_logger;
+  my $root = dir($arg->{dist_root} || '.');
 
   my ($seq) = $class->_load_config({
     root   => $root,
-    logger => $logger,
+    chrome => $arg->{chrome},
     config_class => $arg->{config_class},
   });
 
   my $core_config = $seq->section_named('_')->payload;
 
   my $self = $class->new({
-    logger => $logger,
-    %$core_config
+    %$core_config,
+    chrome => $arg->{chrome},
   });
 
-  $self->core_logger->set_debug(1) if $arg->{core_debug};
-
   for my $section ($seq->sections) {
     next if $section->name eq '_';
 
@@ -377,6 +377,27 @@ sub from_config {
 sub _setup_default_plugins {
   my ($self) = @_;
 
+  my $infix  = $self->__is_minter ? 'minter' : 'builder';
+  my $method = "_setup_default_$infix\_plugins";
+  $self->$method;
+}
+
+sub _setup_default_minter_plugins {
+  my ($self) = @_;
+
+  unless ($self->plugin_named(':DefaultModuleMaker')) {
+    require Dist::Zilla::Plugin::TemplateModule;
+    my $plugin = Dist::Zilla::Plugin::TemplateModule->new({
+      plugin_name => ':DefaultModuleMaker',
+      zilla       => $self,
+    });
+
+    $self->plugins->push($plugin);
+  }
+}
+
+sub _setup_default_builder_plugins {
+  my ($self) = @_;
   unless ($self->plugin_named(':InstallModules')) {
     require Dist::Zilla::Plugin::FinderCode;
     my $plugin = Dist::Zilla::Plugin::FinderCode->new({
@@ -441,11 +462,9 @@ sub _load_config {
   $arg ||= {};
 
   my $config_class = $arg->{config_class} ||= 'Dist::Zilla::Config::Finder';
-  unless (eval "require $config_class; 1") {
-    die "couldn't load $config_class: $@"; ## no critic Carp
-  }
+  Class::MOP::load_class($config_class);
 
-  $arg->{logger}->log_debug(
+  $arg->{chrome}->logger->log_debug(
     { prefix => '[DZ] ' },
     "reading configuration using $config_class"
   );
@@ -517,6 +536,8 @@ sub build { $_[0]->build_in }
 sub build_in {
   my ($self, $root) = @_;
 
+  $self->log_fatal("tried to build with a minter") if $self->__is_minter;
+
   $self->log_fatal("attempted to build " . $self->name . " a second time")
     if $self->built_in;
 
@@ -530,11 +551,10 @@ sub build_in {
 
   $_->register_prereqs for $self->plugins_with(-PrereqSource)->flatten;
 
-  $self->prereq->finalize;
+  $self->prereqs->finalize;
 
-  my $meta   = $self->distmeta;
-  my $prereq = $self->prereq->as_distmeta;
-  $meta->{ $_ } = $prereq->{ $_ } for keys %$prereq;
+  # Barf if someone has already set up a prereqs entry? -- rjbs, 2010-04-13
+  $self->distmeta->{prereqs} = $self->prereqs->as_string_hash;
 
   $_->setup_installer for $self->plugins_with(-InstallTool)->flatten;
 
@@ -555,6 +575,10 @@ sub build_in {
 }
 
 
+sub ensure_built {
+  $_[0]->ensure_built_in;
+}
+
 sub ensure_built_in {
   my ($self, $root) = @_;
 
@@ -568,24 +592,23 @@ sub ensure_built_in {
 
 
 sub build_archive {
-  my ($self, $root) = @_;
+  my ($self, $file) = @_;
 
-  $self->ensure_built_in($root);
+  my $built_in = $self->ensure_built;
 
-  require Archive::Tar;
   my $archive = Archive::Tar->new;
-  my $built_in = $self->built_in;
+
+  $_->before_archive for $self->plugins_with(-BeforeArchive)->flatten;
 
   my %seen_dir;
-
-  for my $file ($self->files->flatten) {
-    my $in = Path::Class::file($file->name)->dir;
+  for my $distfile ($self->files->flatten) {
+    my $in = file($distfile->name)->dir;
     $archive->add_files( $built_in->subdir($in) ) unless $seen_dir{ $in }++;
-    $archive->add_files( $built_in->file( $file->name ) );
+    $archive->add_files( $built_in->file( $distfile->name ) );
   }
 
   ## no critic
-  my $file = Path::Class::file(join(q{},
+  $file ||= file(join(q{},
     $self->name,
     '-',
     $self->version,
@@ -623,7 +646,7 @@ sub _prep_build_root {
   my ($self, $build_root) = @_;
 
   my $default_name = $self->name . q{-} . $self->version;
-  $build_root = Path::Class::dir($build_root || $default_name);
+  $build_root = dir($build_root || $default_name);
 
   $build_root->mkpath unless -d $build_root;
 
@@ -640,7 +663,7 @@ sub _write_out_file {
   # Okay, this is a bit much, until we have ->debug. -- rjbs, 2008-06-13
   # $self->log("writing out " . $file->name);
 
-  my $file_path = Path::Class::file($file->name);
+  my $file_path = file($file->name);
 
   my $to_dir = $build_root->subdir( $file_path->dir );
   my $to = $to_dir->file( $file_path->basename );
@@ -683,10 +706,6 @@ sub clean {
     $self->log("clean: removing $x");
     File::Path::rmtree($x);
   };
-
-  # removing leftovers
-  my @temps = File::Find::Rule->file->name( qr{~$} )->in('.');
-  $self->log("clean: removing $_"), unlink for @temps;
 }
 
 
@@ -694,24 +713,24 @@ sub install {
   my ($self, $arg) = @_;
   $arg ||= {};
 
-  require File::chdir;
   require File::Temp;
-  require Path::Class;
 
-  my $build_root = Path::Class::dir('.build');
+  my $build_root = dir('.build');
   $build_root->mkpath unless -d $build_root;
 
-  my $target = Path::Class::dir( File::Temp::tempdir(DIR => $build_root) );
+  my $target = dir( File::Temp::tempdir(DIR => $build_root) );
   $self->log("building distribution under $target for installation");
   $self->ensure_built_in($target);
 
   eval {
     ## no critic Punctuation
-    local $File::chdir::CWD = $target;
+    my $wd = File::pushd::pushd($target);
     my @cmd = $arg->{install_command}
             ? $arg->{install_command}
-            : ($^X => '-MCPAN' => '-einstall "."');
+            : ($^X => '-MCPAN' =>
+                $^O eq 'MSWin32' ? q{-e"install '.'"} : '-einstall "."');
 
+    $self->log_debug([ 'installing via %s', \@cmd ]);
     system(@cmd) && $self->log_fatal([ "error running %s", \@cmd ]);
   };
 
@@ -733,14 +752,12 @@ sub test {
   Carp::croak("you can't test without any TestRunner plugins")
     unless my @testers = $self->plugins_with(-TestRunner)->flatten;
 
-  require File::chdir;
   require File::Temp;
-  require Path::Class;
 
-  my $build_root = Path::Class::dir('.build');
+  my $build_root = dir('.build');
   $build_root->mkpath unless -d $build_root;
 
-  my $target = Path::Class::dir( File::Temp::tempdir(DIR => $build_root) );
+  my $target = dir( File::Temp::tempdir(DIR => $build_root) );
   $self->log("building test distribution under $target");
 
   local $ENV{AUTHOR_TESTING} = 1;
@@ -748,26 +765,22 @@ sub test {
 
   $self->ensure_built_in($target);
 
-  my $error;
+  my $error = $self->run_tests_in($target);
+
+  $self->log("all's well; removing $target");
+  $target->rmtree;
+}
+
+
+sub run_tests_in {
+  my ($self, $target) = @_;
+
+  Carp::croak("you can't test without any TestRunner plugins")
+    unless my @testers = $self->plugins_with(-TestRunner)->flatten;
 
   for my $tester (@testers) {
-    undef $error;
-    eval {
-      local $File::chdir::CWD = $target;
-      $error = $tester->test( $target );
-      1;
-    } or do {
-      $error = $@;
-    };
-    last if $error;
-  }
-
-  if ($error) {
-    $self->log($error);
-    $self->log_fatal("left failed dist in place at $target");
-  } else {
-    $self->log("all's well; removing $target");
-    $target->rmtree;
+    my $wd = File::pushd::pushd($target);
+    $tester->test( $target );
   }
 }
 
@@ -782,15 +795,13 @@ sub run_in_build {
     $self->plugins_with(-BuildRunner)->sort->reverse->flatten;
 
   require "Config.pm"; # skip autoprereq
-  require File::chdir;
   require File::Temp;
-  require Path::Class;
 
   # dzil-build the dist
-  my $build_root = Path::Class::dir('.build');
+  my $build_root = dir('.build');
   $build_root->mkpath unless -d $build_root;
 
-  my $target    = Path::Class::dir( File::Temp::tempdir(DIR => $build_root) );
+  my $target    = dir( File::Temp::tempdir(DIR => $build_root) );
   my $abstarget = $target->absolute;
   $self->log("building test distribution under $target");
 
@@ -798,7 +809,7 @@ sub run_in_build {
 
   # building the dist for real
   my $ok = eval {
-    local $File::chdir::CWD = $target;
+    my $wd = File::pushd::pushd($target);
     $builders[0]->build;
     local $ENV{PERL5LIB} =
       join $Config::Config{path_sep},
@@ -818,33 +829,16 @@ sub run_in_build {
 }
 
 
-has core_logger => (
+has logger => (
   is   => 'ro',
   isa  => 'Log::Dispatchouli::Proxy', # could be duck typed, I guess
   lazy => 1,
   handles => [ qw(log log_debug log_fatal) ],
   default => sub {
-    $_[0]->logger->proxy({ proxy_prefix => '[DZ] ' })
+    $_[0]->chrome->logger->proxy({ proxy_prefix => '[DZ] ' })
   },
 );
 
-has logger => (
-  is   => 'ro',
-  isa  => 'Log::Dispatchouli',
-  lazy => 1,
-  builder => 'default_logger',
-);
-
-sub default_logger {
-  return Log::Dispatchouli->new({
-    ident     => 'Dist::Zilla',
-    to_stdout => 1,
-    log_pid   => 0,
-    to_self   => ($ENV{DZIL_TESTING} ? 1 : 0),
-    quiet_fatal => 'stdout',
-  });
-}
-
 sub BUILD {
   my ($self, $arg) = @_;
 
@@ -858,6 +852,178 @@ around dump_config => sub {
   return $config;
 };
 
+sub _global_config {
+  my ($self) = @_;
+
+  my $homedir = File::HomeDir->my_home
+    or Carp::croak("couldn't determine home directory");
+
+  my $file = dir($homedir)->file('.dzil');
+  return unless -e $file;
+
+  if (-d $file) {
+    return Dist::Zilla::Config::Finder->new->read_config({
+      root     =>  dir($homedir)->subdir('.dzil'),
+      basename => 'config',
+    });
+  } else {
+    return Dist::Zilla::Config::Finder->new->read_config({
+      root     => dir($homedir),
+      filename => '.dzil',
+    });
+  }
+}
+
+sub _global_config_for {
+  my ($self, $plugin_class) = @_;
+
+  return {} unless my $global_config = $self->_global_config;
+
+  my ($section) = grep { ($_->package||'') eq $plugin_class }
+                  $global_config->sections;
+
+  return {} unless $section;
+
+  return $section->payload;
+}
+
+#####################################
+## BEGIN DIST MINTING CODE
+#####################################
+
+sub _new_from_profile {
+  my ($class, $profile_name, $arg) = @_;
+  $arg ||= {};
+
+  my $config_class = $arg->{config_class} ||= 'Dist::Zilla::Config::Finder';
+  Class::MOP::load_class($config_class);
+
+  $arg->{chrome}->logger->log_debug(
+    { prefix => '[DZ] ' },
+    "reading configuration using $config_class"
+  );
+
+  my $profile_dir = dir( File::HomeDir->my_home )->subdir(qw(.dzil profiles));
+
+  my $sequence;
+
+  if ($profile_name eq 'default' and ! -e $profile_dir->subdir('default')) {
+    $arg->{chrome}->logger->log_fatal(
+      { prefix => '[DZ] ' },
+      "no default dist minting profile available"
+    );
+  } else {
+    ($sequence) = $config_class->new->read_config({
+      root     => $profile_dir->subdir($profile_name),
+      basename => 'profile',
+    });
+  }
+
+  my $self = $class->new({
+    %{ $sequence->section_named('_')->payload },
+    name   => $arg->{name},
+    chrome => $arg->{chrome},
+    root   => $profile_dir->subdir($profile_name),
+    __is_minter => 1,
+  });
+
+  for my $section ($sequence->sections) {
+    next if $section->name eq '_';
+
+    my ($name, $plugin_class, $arg) = (
+      $section->name,
+      $section->package,
+      $section->payload,
+    );
+
+    $self->log_fatal("$name arguments attempted to override plugin name")
+      if defined $arg->{plugin_name};
+
+    $self->log_fatal("$name arguments attempted to override plugin name")
+      if defined $arg->{zilla};
+
+    my $plugin = $plugin_class->new(
+      $arg->merge({
+        plugin_name => $name,
+        zilla       => $self,
+      }),
+    );
+
+    my $version = $plugin->VERSION || 0;
+
+    $plugin->log_debug([ 'online, %s v%s', $plugin->meta->name, $version ]);
+
+    $self->plugins->push($plugin);
+  }
+
+  $self->_setup_default_plugins;
+
+  return $self;
+}
+
+# XXX: This is here only because we have not yet broken Zilla into a abstract
+# base class with Minter and Builder subclasses. -- rjbs, 2010-05-03
+has __is_minter => (
+  is  => 'ro',
+  isa => Bool,
+  default => 0,
+);
+
+sub mint_dist {
+  my ($self, $arg) = @_;
+
+  $self->log_fatal("tried to mint with a builder") unless $self->__is_minter;
+
+  my $name = $self->name;
+  my $dir  = dir($name);
+  $self->log_fatal("./$name already exists") if -e $dir;
+
+  $dir = $dir->absolute;
+
+  # XXX: We should have a way to get more than one module name in, and to
+  # supply plugin names for the minter to use. -- rjbs, 2010-05-03
+  my @modules = do {
+    (my $module_name = $name) =~ s/-/::/g;
+    ({ name => $module_name });
+  };
+
+  $self->log("making directory ./$name");
+  $dir->mkpath;
+
+  my $wd = File::pushd::pushd($self->root);
+
+  $_->before_mint  for $self->plugins_with(-BeforeMint)->flatten;
+  $_->gather_files for $self->plugins_with(-FileGatherer)->flatten;
+
+  for my $module (@modules) {
+    my $minter = $self->plugin_named(
+      $module->{minter_name} || ':DefaultModuleMaker'
+    );
+    
+    $minter->make_module({ name => $module->{name} })
+  }
+
+  $_->prune_files  for $self->plugins_with(-FilePruner)->flatten;
+  $_->munge_files  for $self->plugins_with(-FileMunger)->flatten;
+
+  $self->_check_dupe_files;
+
+  $self->log("writing files to $dir");
+
+  for my $file ($self->files->flatten) {
+    $self->_write_out_file($file, $dir);
+  }
+
+  $_->after_mint({ mint_root => $dir })
+    for $self->plugins_with(-AfterMint)->flatten;
+
+  $self->log("dist minted in ./$name");
+}
+
+#####################################
+## END DIST MINTING CODE
+#####################################
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -870,7 +1036,7 @@ Dist::Zilla - distribution builder; installer not included!
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
@@ -972,14 +1138,34 @@ This is a hashref containing the metadata about this distribution that
 will be stored in META.yml or META.json.  You should not alter the
 metadata in this hash; use a MetaProvider plugin instead.
 
-=head2 prereq
+=head2 prereqs
 
-This is a hashref of module prerequisites.  This attribute is likely to get
-greatly overhauled, or possibly replaced with a method based on other
-(private?) attributes.
+This is a L<Dist::Zilla::Prereqs> object, which is a thin layer atop
+L<CPAN::Meta::Prereqs>, and describes the distribution's prerequisites.
 
-I<Actually>, it is more likely that this attribute will contain an object in
-the future.
+=head2 logger
+
+This attribute stores a L<Log::Dispatchouli::Proxy> object, used to log
+messages.  By default, a proxy to the dist's L<Chrome|Dist::Zilla::Chrome> is
+taken.
+
+The following methods are delegated from the Dist::Zilla object to the logger:
+
+=over 4
+
+=item *
+
+log
+
+=item *
+
+log_debug
+
+=item *
+
+log_fatal
+
+=back
 
 =head1 METHODS
 
@@ -1039,10 +1225,10 @@ C<$root> (or the default root, if no root is given), no exception is raised.
 
 =head2 build_archive
 
-  $dist->build_archive($root);
+  $dist->build_archive;
 
-This method will ensure that the dist has been built in the given root, and
-will then build a tarball of that directory in the current directory.
+This method will ensure that the dist has been built, and will then build a
+tarball of the build directory in the current directory.
 
 =head2 release
 
@@ -1062,26 +1248,34 @@ by the loaded plugins.
 
 This method builds a new copy of the distribution and tests it.
 
+=head2 run_tests_in
+
+  my $error = $zilla->run_tests_in($directory);
+
+This method runs the tests in $directory (a Path::Class::Dir), which
+must contain an already-built copy of the distribution.  It will throw an
+exception if there are test failures.
+
+It does I<not> set any of the C<*_TESTING> environment variables, nor
+does it clean up C<$directory> afterwards.
+
 =head2 run_in_build
 
-=head2 log
+  $zilla->run_in_build(\@cmd);
 
-  $zilla->log($message);
-
-This method logs the given message.
+This method makes a temporary directory, builds the distribution there,
+executes the dist's first L<BuildRunner|Dist::Zilla::Role::BuildRunner>, and
+then runs the given command in the build directory.  If the command exits
+non-zero, the directory will be left in place.
 
 =head1 SUPPORT
 
 There are usually people on C<irc.perl.org> in C<#distzilla>, even if they're
 idling.
 
-There is a mailing list to discuss Dist::Zilla, which you can join here:
-
-L<http://www.listbox.com/subscribe/?list_id=139292>
-
-The archive is available here:
-
-L<http://listbox.com/member/archive/139292>
+There is a mailing list to discuss Dist::Zilla.  You can L<join the
+list|http://www.listbox.com/subscribe/?list_id=139292> or L<browse the
+archives|http://listbox.com/member/archive/139292>.
 
 =head1 AUTHOR
 
