@@ -1,7 +1,9 @@
 use strict;
 use warnings;
 package Dist::Zilla::App;
-$Dist::Zilla::App::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::App::VERSION = '3.101390';
+}
 # ABSTRACT: Dist::Zilla's App::Cmd
 use App::Cmd::Setup 0.307 -app; # need ->app in Result of Tester, GLD vers
 
@@ -11,41 +13,6 @@ use File::HomeDir ();
 use Moose::Autobox;
 use Path::Class;
 
-sub config {
-  my ($self) = @_;
-
-  my $homedir = File::HomeDir->my_home
-    or Carp::croak("couldn't determine home directory");
-
-  my $file = dir($homedir)->file('.dzil');
-  return unless -e $file;
-
-  if (-d $file) {
-    return Dist::Zilla::Config::Finder->new->read_config({
-      root     =>  dir($homedir)->subdir('.dzil'),
-      basename => 'config',
-    });
-  } else {
-    return Dist::Zilla::Config::Finder->new->read_config({
-      root     => dir($homedir),
-      filename => '.dzil',
-    });
-  }
-}
-
-sub config_for {
-  my ($self, $plugin_class) = @_;
-
-  return {} unless $self->config;
-
-  my ($section) = grep { ($_->package||'') eq $plugin_class }
-                  $self->config->sections;
-
-  return {} unless $section;
-
-  return $section->payload;
-}
-
 sub global_opt_spec {
   return (
     [ "verbose|v:s@", "log additional output" ],
@@ -56,37 +23,55 @@ sub global_opt_spec {
 }
 
 
+sub chrome {
+  my ($self) = @_;
+  require Dist::Zilla::Chrome::Term;
+
+  return $self->{__chrome__} if $self->{__chrome__};
+
+  $self->{__chrome__} = Dist::Zilla::Chrome::Term->new;
+
+  my @v_plugins = $self->global_options->verbose
+                ? grep { length } @{ $self->global_options->verbose }
+                : ();
+
+  my $verbose = $self->global_options->verbose && ! @v_plugins;
+
+  $self->{__chrome__}->logger->set_debug($verbose ? 1 : 0);
+
+  return $self->{__chrome__};
+}
+
 sub zilla {
   my ($self) = @_;
 
   require Dist::Zilla;
 
-  return $self->{__PACKAGE__}{zilla} ||= do {
+  return $self->{'' . __PACKAGE__}{zilla} ||= do {
     my @v_plugins = $self->global_options->verbose
                   ? grep { length } @{ $self->global_options->verbose }
                   : ();
 
     my $verbose = $self->global_options->verbose && ! @v_plugins;
 
-    my $logger = Dist::Zilla->default_logger;
-    $logger->set_debug($verbose ? 1 : 0);
+    $self->chrome->logger->set_debug($verbose ? 1 : 0);
 
     my $core_debug = grep { m/\A[-_]\z/ } @v_plugins;
 
     my $zilla = Dist::Zilla->from_config({
-      logger     => $logger,
-      core_debug => $core_debug,
+      chrome => $self->chrome,
     });
 
-    $zilla->controller($self);
-
     $zilla->logger->set_debug($verbose ? 1 : 0);
 
     VERBOSE_PLUGIN: for my $plugin_name (grep { ! m{\A[-_]\z} } @v_plugins) {
-      $zilla->log_fatal("can't find plugin $plugin_name to set debug mode")
-        unless my $plugin = $zilla->plugin_named($plugin_name);
+      my @plugins = grep { $_->plugin_name =~ /\b\Q$plugin_name\E\b/ }
+                    $zilla->plugins->flatten;
 
-      $plugin->logger->set_debug(1);
+      $zilla->log_fatal("can't find plugins matching $plugin_name to set debug")
+        unless @plugins;
+
+      $_->logger->set_debug(1) for @plugins;
     }
 
     $zilla;
@@ -104,7 +89,7 @@ Dist::Zilla::App - Dist::Zilla's App::Cmd
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 METHODS
 
