@@ -1,7 +1,9 @@
 use strict;
 use warnings;
 package Dist::Zilla::App::Command;
-$Dist::Zilla::App::Command::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::App::Command::VERSION = '3.101390';
+}
 # ABSTRACT: base class for dzil commands
 use App::Cmd::Setup -command;
 use Moose::Autobox;
@@ -11,15 +13,15 @@ sub zilla {
   return $_[0]->app->zilla;
 }
 
-
 sub config {
   my ($self) = @_;
-  return $self->{__PACKAGE__}{config} ||= $self->app->config_for(ref $self);
+  return $self->{'' . __PACKAGE__}{config}
+    ||= $self->zilla->_global_config_for(ref $self);
 }
 
 
 sub log {
-  $_[0]->zilla->log($_[1]);
+  $_[0]->app->chrome->logger->log($_[1]);
 }
 
 1;
@@ -33,7 +35,7 @@ Dist::Zilla::App::Command - base class for dzil commands
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 METHODS
 
@@ -44,14 +46,9 @@ been constructed, one will be by calling C<< Dist::Zilla->from_config >>.
 
 (This method just delegates to the Dist::Zilla::App object!)
 
-=head2 config
-
-This method returns the configuration for the current command.
-
 =head2 log
 
-This method calls the C<log> method of the command's L<Dist::Zilla|Dist::Zilla>
-object.
+This method calls the C<log> method of the application's chrome.
 
 =head1 AUTHOR
 
