@@ -1,8 +1,12 @@
 package Dist::Zilla::Config;
-$Dist::Zilla::Config::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Config::VERSION = '3.101390';
+}
 use Moose::Role;
 # ABSTRACT: stored configuration loader role
 
+use Config::MVP 0.100780; # fix mvp_* method laziness
+
 with q(Config::MVP::Reader) => { -excludes => 'build_assembler' };
 
 use Dist::Zilla::Util::MVPAssembler;
@@ -34,7 +38,7 @@ Dist::Zilla::Config - stored configuration loader role
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
