@@ -1,5 +1,7 @@
 package Dist::Zilla::File::FromCode;
-$Dist::Zilla::File::FromCode::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::File::FromCode::VERSION = '3.101390';
+}
 # ABSTRACT: a file whose content is (re-)built on demand
 use Moose;
 
@@ -13,6 +15,8 @@ has code => (
 sub content {
   my ($self) = @_;
 
+  confess "cannot set content of a FromCode file" if @_ > 1;
+
   my $code = $self->code;
   return $self->$code;
 }
@@ -31,7 +35,7 @@ Dist::Zilla::File::FromCode - a file whose content is (re-)built on demand
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
