@@ -1,10 +1,19 @@
 package Dist::Zilla::Plugin::FakeRelease;
-$Dist::Zilla::Plugin::FakeRelease::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Plugin::FakeRelease::VERSION = '3.101390';
+}
 # ABSTRACT: fake plugin to test release
 
 use Moose;
 with 'Dist::Zilla::Role::Releaser';
 
+has user => (
+  is   => 'ro',
+  isa  => 'Str',
+  required => 1,
+  default  => 'AUTHORID',
+);
+
 sub release {
   my $self = shift;
 
@@ -32,7 +41,7 @@ Dist::Zilla::Plugin::FakeRelease - fake plugin to test release
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
