@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::MakeMaker;
-$Dist::Zilla::Plugin::MakeMaker::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Plugin::MakeMaker::VERSION = '3.101390';
+}
 
 # ABSTRACT: build a Makefile.PL that uses ExtUtils::MakeMaker
 use Moose;
@@ -30,8 +32,18 @@ use ExtUtils::MakeMaker {{ $eumm_version }};
 
 my {{ $WriteMakefileArgs }}
 
-delete $WriteMakefileArgs{BUILD_REQUIRES}
-  unless eval { ExtUtils::MakeMaker->VERSION(6.56) };
+unless ( eval { ExtUtils::MakeMaker->VERSION(6.56) } ) {
+  my $br = delete $WriteMakefileArgs{BUILD_REQUIRES};
+  my $pp = $WriteMakefileArgs{PREREQ_PM}; 
+  for my $mod ( keys %$br ) {
+    if ( exists $pp->{$mod} ) {
+      $pp->{$mod} = $br->{$mod} if $br->{$mod} > $pp->{$mod}; 
+    }
+    else {
+      $pp->{$mod} = $br->{$mod};
+    }
+  }
+}
 
 delete $WriteMakefileArgs{CONFIGURE_REQUIRES}
   unless eval { ExtUtils::MakeMaker->VERSION(6.52) };
@@ -87,8 +99,16 @@ sub setup_installer {
     );
   }
 
-  my $meta_prereq = $self->zilla->prereq->as_distmeta;
-  my $perl_prereq = delete $meta_prereq->{requires}{perl};
+  my $prereqs = $self->zilla->prereqs;
+  my $perl_prereq = $prereqs->requirements_for(qw(runtime requires))
+                  ->as_string_hash->{perl};
+
+  my $prereqs_dump = sub {
+    $prereqs->requirements_for(@_)
+            ->clone
+            ->clear_requirement('perl')
+            ->as_string_hash;
+  };
 
   my %write_makefile_args = (
     DISTNAME  => $self->zilla->name,
@@ -99,9 +119,9 @@ sub setup_installer {
     LICENSE   => $self->zilla->license->meta_yml_name,
     EXE_FILES => [ @exe_files ],
 
-    CONFIGURE_REQUIRES => delete $meta_prereq->{configure_requires},
-    BUILD_REQUIRES     => delete $meta_prereq->{build_requires},
-    PREREQ_PM          => delete $meta_prereq->{requires},
+    CONFIGURE_REQUIRES => $prereqs_dump->(qw(configure requires)),
+    BUILD_REQUIRES     => $prereqs_dump->(qw(build     requires)),
+    PREREQ_PM          => $prereqs_dump->(qw(runtime   requires)),
 
     test => { TESTS => join q{ }, sort keys %test_dirs },
   );
@@ -112,6 +132,8 @@ sub setup_installer {
     [ \%write_makefile_args ],
     [ '*WriteMakefileArgs' ],
   );
+  $makefile_args_dumper->Sortkeys( 1 );
+  $makefile_args_dumper->Indent( 1 );
 
   my $content = $self->fill_in_string(
     $template,
@@ -140,16 +162,19 @@ has __write_makefile_args => (
 
 sub build {
   my $self = shift;
+
   system($^X => 'Makefile.PL') and die "error with Makefile.PL\n";
   system('make')               and die "error running make\n";
+
   return;
 }
 
 sub test {
   my ( $self, $target ) = @_;
-  ## no critic Punctuation
+
   $self->build;
   system('make test') and die "error running make test\n";
+
   return;
 }
 
@@ -172,7 +197,7 @@ Dist::Zilla::Plugin::MakeMaker - build a Makefile.PL that uses ExtUtils::MakeMak
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
