@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::ManifestSkip;
-$Dist::Zilla::Plugin::ManifestSkip::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Plugin::ManifestSkip::VERSION = '3.101390';
+}
 # ABSTRACT: decline to build files that appear in a MANIFEST.SKIP-like file
 use Moose;
 with 'Dist::Zilla::Role::FilePruner';
@@ -15,7 +17,11 @@ sub prune_files {
   my $skip = ExtUtils::Manifest::maniskip($self->skipfile);
 
   my $files = $self->zilla->files;
-  @$files = grep { ! $skip->($_->name) } @$files;
+  @$files = grep {
+    $skip->($_->name)
+    ? do { $self->log_debug([ 'pruning %s', $_->name ]); 0 }
+    : 1
+  } @$files;
 
   return;
 }
@@ -33,7 +39,7 @@ Dist::Zilla::Plugin::ManifestSkip - decline to build files that appear in a MANI
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
