@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::ModuleBuild;
-$Dist::Zilla::Plugin::ModuleBuild::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Plugin::ModuleBuild::VERSION = '3.101390';
+}
 # ABSTRACT: build a Build.PL that uses Module::Build
 use List::MoreUtils qw(any uniq);
 use Moose;
@@ -63,6 +65,18 @@ sub setup_installer {
   $self->log_fatal("can't install files with whitespace in their names")
     if grep { /\s/ } @exe_files;
 
+  my $prereqs = $self->zilla->prereqs;
+  my %prereqs = (
+    configure_requires => $prereqs->requirements_for(qw(configure requires)),
+    build_requires     => $prereqs->requirements_for(qw(build     requires)),
+    requires           => $prereqs->requirements_for(qw(runtime   requires)),
+    recommends         => $prereqs->requirements_for(qw(runtime   recommends)),
+  );
+
+  $prereqs{build_requires} = $prereqs{build_requires}->clone->add_requirements(
+    $prereqs->requirements_for(qw(test requires))
+  );
+
   my %module_build_args = (
     module_name   => $name,
     license       => $self->zilla->license->meta_yml_name,
@@ -73,9 +87,7 @@ sub setup_installer {
     script_files  => \@exe_files,
     ($self->zilla->_share_dir ? (share_dir => $self->zilla->_share_dir) : ()),
 
-    # I believe it is a happy coincidence, for the moment, that this happens to
-    # return just the same thing that is needed here. -- rjbs, 2010-01-22
-    $self->zilla->prereq->as_distmeta->flatten,
+    (map {; $_ => $prereqs{$_}->as_string_hash } keys %prereqs),
   );
 
   $self->__module_build_args(\%module_build_args);
@@ -84,6 +96,8 @@ sub setup_installer {
     [ \%module_build_args ],
     [ '*module_build_args' ],
   );
+  $module_build_dumper->Sortkeys( 1 );
+  $module_build_dumper->Indent( 1 );
 
   my $content = $self->fill_in_string(
     $template,
@@ -110,16 +124,19 @@ has __module_build_args => (
 
 sub build {
   my $self = shift;
+
   system($^X => 'Build.PL') and die "error with Build.PL\n";
   system('./Build')         and die "error running ./Build\n";
+
   return;
 }
 
 sub test {
-  my ( $self, $target ) = @_;
-  ## no critic Punctuation
+  my ($self, $target) = @_;
+
   $self->build;
   system('./Build test') and die "error running ./Build test\n";
+
   return;
 }
 
@@ -136,7 +153,7 @@ Dist::Zilla::Plugin::ModuleBuild - build a Build.PL that uses Module::Build
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
