@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::NextRelease;
-$Dist::Zilla::Plugin::NextRelease::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Plugin::NextRelease::VERSION = '3.101390';
+}
 # ABSTRACT: update the next release number in your changelog
 
 use Moose;
@@ -14,14 +16,22 @@ use String::Formatter 0.100680 stringf => {
   input_processor => 'require_single_input',
   string_replacer => 'method_replace',
   codes => {
-    v => sub { $_[0]->version },
+    v => sub { $_[0]->zilla->version },
     d => sub {
-      DateTime->from_epoch(epoch => $^T, time_zone => 'local')
+      DateTime->from_epoch(epoch => $^T, time_zone => $_[0]->time_zone)
               ->format_cldr($_[1]),
-    }
+    },
+    t => sub { "\t" },
+    n => sub { "\n" },
   },
 };
 
+has time_zone => (
+  is => 'ro',
+  isa => 'Str', # should be more validated later -- apocal
+  default => 'local',
+);
+
 has format => (
   is  => 'ro',
   isa => 'Str', # should be more validated Later -- rjbs, 2008-06-05
@@ -34,10 +44,17 @@ has filename => (
   default => 'Changes',
 );
 
+has update_filename => (
+  is  => 'ro',
+  isa => 'Str',
+  lazy    => 1,
+  default => sub { $_[0]->filename },
+);
+
 sub section_header {
   my ($self) = @_;
 
-  return _format_version($self->format, $self->zilla);
+  return _format_version($self->format, $self);
 }
 
 sub munge_files {
@@ -55,6 +72,7 @@ sub munge_files {
     },
   );
 
+  $self->log_debug([ 'updating contents of %s in memory', $file->name ]);
   $file->content($content);
 }
 
@@ -77,11 +95,14 @@ sub after_release {
   $content =~ s{ (\Q$delim->[0]\E \s*) \$NEXT (\s* \Q$delim->[1]\E) }
                {$1\$NEXT$2\n\n$header}xs;
 
+  my $update_fn = $self->update_filename;
+  $self->log_debug([ 'updating contents of %s on disk', $update_fn ]);
+
   # and finally rewrite the changelog on disk
-  open my $out_fh, '>', $filename
-    or Carp::croak("can't open $filename for writing: $!");
-  print $out_fh $content or Carp::croak("error writing to $filename: $!");
-  close $out_fh or Carp::croak("error closing $filename: $!");
+  open my $out_fh, '>', $update_fn
+    or Carp::croak("can't open $update_fn for writing: $!");
+  print $out_fh $content or Carp::croak("error writing to $update_fn: $!");
+  close $out_fh or Carp::croak("error closing $update_fn: $!");
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -97,7 +118,7 @@ Dist::Zilla::Plugin::NextRelease - update the next release number in your change
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 SYNOPSIS
 
@@ -140,9 +161,44 @@ The module accepts the following options in its F<dist.ini> section:
 
 =over 4
 
-=item * filename - the name of your changelog file. defaults to F<Changes>.
+=item filename
 
-=item * format - the date format. defaults to C<%-9v %{yyyy-MM-dd HH:mm:ss VVVV}d>.
+the name of your changelog file;  defaults to F<Changes>
+
+=item update_filename
+
+the file to which to write an updated changelog to; defaults to the C<filename>
+
+=item format
+
+sprintf-like string used to compute the next value of C<{{$NEXT}}>;
+defaults to C<%-9v %{yyyy-MM-dd HH:mm:ss VVVV}d>
+
+=item time_zone
+
+the timezone to use when generating the date;  defaults to I<local>
+
+=back
+
+The module allows the following sprintf-like format codes in the format:
+
+=over 4
+
+=item *
+
+v - the version of the dist
+
+=item *
+
+d - the CLDR format for L<DateTime>
+
+=item *
+
+n - a newline
+
+=item *
+
+t - a tab
 
 =back
 
