@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::PkgVersion;
-$Dist::Zilla::Plugin::PkgVersion::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Plugin::PkgVersion::VERSION = '3.101390';
+}
 # ABSTRACT: add a $VERSION to your packages
 use Moose;
 with(
@@ -48,24 +50,37 @@ sub munge_perl {
     my $code_only = $document->clone;
     $code_only->prune("PPI::Token::$_") for qw(Comment Pod Quote Regexp);
     if ($code_only->serialize =~ /\$VERSION\s*=/sm) {
-      $self->log(sprintf('skipping %s: assigns to $VERSION', $file->name));
+      $self->log([ 'skipping %s: assigns to $VERSION', $file->name ]);
       return;
     }
   }
 
   return unless my $package_stmts = $document->find('PPI::Statement::Package');
 
+  my %seen_pkg;
+
   for my $stmt (@$package_stmts) {
     my $package = $stmt->namespace;
 
+    if ($seen_pkg{ $package }++) {
+      $self->log([ 'skipping package re-declaration for %s', $package ]);
+      next;
+    }
+
     # the \x20 hack is here so that when we scan *this* document we don't find
     # an assignment to version; it shouldn't be needed, but it's been annoying
     # enough in the past that I'm keeping it here until tests are better
-    my $perl = "\$$package\::VERSION\x20=\x20'$version';\n";
+    my $perl = "BEGIN {\n  \$$package\::VERSION\x20=\x20'$version';\n}\n";
 
     my $version_doc = PPI::Document->new(\$perl);
     my @children = $version_doc->schildren;
 
+    $self->log_debug([
+      'adding $VERSION assignment to %s in %s',
+      $package,
+      $file->name,
+    ]);
+
     Carp::carp("error inserting version in " . $file->name)
       unless $stmt->insert_after($children[0]->clone)
       and    $stmt->insert_after( PPI::Token::Whitespace->new("\n") );
@@ -87,7 +102,7 @@ Dist::Zilla::Plugin::PkgVersion - add a $VERSION to your packages
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
