@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::PruneCruft;
-$Dist::Zilla::Plugin::PruneCruft::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Plugin::PruneCruft::VERSION = '3.101390';
+}
 # ABSTRACT: prune stuff that you probably don't mean to include
 use Moose;
 use Moose::Autobox;
@@ -23,7 +25,11 @@ sub prune_files {
 
   my $files = $self->zilla->files;
 
-  @$files = $files->grep(sub { ! $self->exclude_file($_) })->flatten;
+  @$files = grep {
+    $self->exclude_file($_)
+    ? do { $self->log_debug([ 'pruning %s', $_->name ]); 0 }
+    : 1
+  } @$files;
 
   return;
 }
@@ -41,7 +47,7 @@ Dist::Zilla::Plugin::PruneCruft - prune stuff that you probably don't mean to in
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 SYNOPSIS
 
