@@ -1,5 +1,7 @@
 package Dist::Zilla::Role::FileInjector;
-$Dist::Zilla::Role::FileInjector::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Role::FileInjector::VERSION = '3.101390';
+}
 use Moose::Autobox;
 # ABSTRACT: something that can add files to the distribution
 use Moose::Role;
@@ -9,8 +11,12 @@ sub add_file {
   my ($self, $file) = @_;
   my ($pkg, undef, $line) = caller;
 
-  $file->meta->get_attribute('added_by')->set_value($file, "$pkg line $line");
-  # $self->log($file->name . " added by $pkg");
+  $file->meta->get_attribute('added_by')->set_value(
+    $file,
+    sprintf("%s (%s line %s)", $self->plugin_name, $pkg, $line),
+  );
+
+  $self->log_debug([ 'adding file %s', $file->name ]);
   $self->zilla->files->push($file);
 }
 
@@ -26,7 +32,7 @@ Dist::Zilla::Role::FileInjector - something that can add files to the distributi
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
