@@ -1,11 +1,14 @@
 package Dist::Zilla::Role::Plugin;
-$Dist::Zilla::Role::Plugin::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Role::Plugin::VERSION = '3.101390';
+}
 # ABSTRACT: something that gets plugged in to Dist::Zilla
 use Moose::Role;
 
 with 'Dist::Zilla::Role::ConfigDumper';
 
 use Params::Util qw(_HASHLIKE);
+use MooseX::Types;
 
 use namespace::autoclean;
 
@@ -19,7 +22,7 @@ has plugin_name => (
 
 has zilla => (
   is  => 'ro',
-  isa => 'Dist::Zilla',
+  isa => class_type('Dist::Zilla'),
   required => 1,
   weak_ref => 1,
 );
@@ -30,7 +33,7 @@ has logger => (
   lazy => 1,
   handles => [ qw(log log_debug log_fatal) ],
   default => sub {
-    $_[0]->zilla->logger->proxy({
+    $_[0]->zilla->chrome->logger->proxy({
       proxy_prefix => '[' . $_[0]->plugin_name . '] ',
     });
   },
@@ -53,7 +56,7 @@ Dist::Zilla::Role::Plugin - something that gets plugged in to Dist::Zilla
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 DESCRIPTION
 
