@@ -1,12 +1,15 @@
 package Dist::Zilla::Tester;
-$Dist::Zilla::Tester::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Tester::VERSION = '3.101390';
+}
 use Moose;
 extends 'Dist::Zilla';
 # ABSTRACT: a testing-enabling stand-in for  Dist::Zilla
 
 use autodie;
+use Dist::Zilla::Chrome::Test;
 use File::Copy::Recursive qw(dircopy);
-use File::chdir;
+use File::pushd ();
 use File::Spec;
 use File::Temp;
 use Path::Class;
@@ -51,6 +54,7 @@ around from_config => sub {
   }
 
   local $arg->{dist_root} = "$root";
+  local $arg->{chrome} = Dist::Zilla::Chrome::Test->new;
 
   local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
 
@@ -66,7 +70,7 @@ around build_in => sub {
 
   # XXX: We *must eliminate* the need for this!  It's only here because right
   # now building a dist with (root <> cwd) doesn't work. -- rjbs, 2010-03-08
-  local $CWD = $self->root;
+  my $wd = File::pushd::pushd($self->root);
 
   $target ||= do {
     my $target = dir($self->tempdir)->subdir('build');
@@ -82,20 +86,11 @@ around release => sub {
 
   # XXX: We *must eliminate* the need for this!  It's only here because right
   # now building a dist with (root <> cwd) doesn't work. -- rjbs, 2010-03-08
-  local $CWD = $self->root;
+  my $wd = File::pushd::pushd($self->root);
 
   return $self->$orig;
 };
 
-
-sub default_logger {
-  return Log::Dispatchouli->new({
-    ident   => 'Dist::Zilla::Tester',
-    log_pid => 0,
-    to_self => 1,
-  });
-}
-
 has tempdir => (
   is   => 'ro',
   writer   => '_set_tempdir',
@@ -104,17 +99,17 @@ has tempdir => (
 
 sub clear_log_events {
   my ($self) = @_;
-  $self->logger->clear_events;
+  $self->chrome->logger->clear_events;
 }
 
 sub log_events {
   my ($self) = @_;
-  $self->logger->events;
+  $self->chrome->logger->events;
 }
 
 sub log_messages {
   my ($self) = @_;
-  [ map {; $_->{message} } @{ $self->logger->events } ];
+  [ map {; $_->{message} } @{ $self->chrome->logger->events } ];
 }
 
 sub slurp_file {
@@ -138,7 +133,7 @@ Dist::Zilla::Tester - a testing-enabling stand-in for  Dist::Zilla
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 AUTHOR
 
