@@ -1,17 +1,14 @@
 package Dist::Zilla::Types;
-$Dist::Zilla::Types::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Types::VERSION = '3.101390';
+}
 # ABSTRACT: dzil-specific type library
 
-use MooseX::Types -declare => [qw(DistName License)];
+
+use MooseX::Types -declare => [qw(License)];
 use MooseX::Types::Moose qw(Str);
 
-subtype DistName,
-  as Str,
-  where { !/::/ },
-  message { "$_ looks like a module name, not a dist name" };
-
-subtype License,
-  as class_type('Software::License');
+subtype License, as class_type('Software::License');
 
 1;
 
@@ -24,7 +21,15 @@ Dist::Zilla::Types - dzil-specific type library
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
+
+=head1 OVERVIEW
+
+This library provides L<MooseX::Types> types for use by Dist::Zilla.  These
+types are not (yet?) for public consumption, and you should not rely on them.
+
+Dist::Zilla uses a number of types found in L<MooseX::Types::Perl>.  Maybe
+that's what you want.
 
 =head1 AUTHOR
 
