@@ -1,10 +1,14 @@
 package Dist::Zilla::Util::MVPAssembler;
-$Dist::Zilla::Util::MVPAssembler::VERSION = '2.100870';
+BEGIN {
+  $Dist::Zilla::Util::MVPAssembler::VERSION = '3.101390';
+}
 use Moose;
 extends 'Config::MVP::Assembler';
 with 'Config::MVP::Assembler::WithBundles';
 # ABSTRACT: Dist::Zilla-specific subclass of Config::MVP::Assembler
 
+use Dist::Zilla::Util;
+
 sub expand_package {
   my $str = Dist::Zilla::Util->expand_config_package_name($_[1]);
   return $str;
@@ -29,7 +33,7 @@ Dist::Zilla::Util::MVPAssembler - Dist::Zilla-specific subclass of Config::MVP::
 
 =head1 VERSION
 
-version 2.100870
+version 3.101390
 
 =head1 AUTHOR
 
